import requests

class LogesticSMS:
    def __init__(self, base_url, username, password):
        self.base_url = base_url
        self.username = username
        self.password = password
        self.token = None

    def login(self):
        """
        Logs in to the Logestic SMS API and retrieves the authentication token.
        """
        url = f"{self.base_url}/api/v1/login"
        payload = {
            'username': self.username,
            'password': self.password
        }
        response = requests.post(url, data=payload)
        if response.status_code == 200:
            self.token = response.json().get('data', {}).get('token')
            if not self.token:
                raise Exception("Token not found in response")
        else:
            print(f"Login failed: {response.status_code}")
            print(response.json())
        return response

    def send_one_sms(self, receptor, message, sender):
        """
        Sends a single SMS to the specified receptor.
        
        Parameters:
        - receptor: The phone number of the message recipient.
        - message: The message content.
        - sender: The sender ID.
        
        Returns:
        - response: The response object from the API request.
        """
        if not self.token:
            raise Exception("You must log in first before sending an SMS")

        url = f"{self.base_url}/api/v1/sms/send"
        headers = {
            'X-API-TOKEN': self.token
        }
        payload = {
            'receptor': receptor,
            'message': message,
            'sender': sender
        }
        response = requests.post(url, headers=headers, data=payload)
        return response

    def track_sms(self, tracking_id):
        """
        Tracks the status of a sent SMS using its tracking ID.
        
        Parameters:
        - tracking_id: The unique tracking ID of the SMS.
        
        Returns:
        - response: The response object from the API request.
        """
        if not self.token:
            raise Exception("You must log in first before tracking an SMS")

        url = f"{self.base_url}/api/v1/sms/tracking"
        headers = {
            'X-API-TOKEN': self.token
        }
        params = {
            'tracking_id': tracking_id
        }
        response = requests.get(url, headers=headers, params=params)
        return response

    def get_account_info(self):
        """
        Retrieves the account information and remaining SMS charge.
        
        Returns:
        - response: The response object from the API request.
        """
        if not self.token:
            raise Exception("You must log in first before getting account info")

        url = f"{self.base_url}/api/v1/account/info"
        headers = {
            'X-API-TOKEN': self.token
        }
        response = requests.get(url, headers=headers)
        return response

# Usage example
logestic_sms = LogesticSMS(
    base_url='https://api.logisticsms.ir',
    username='your-username',  # Replace with actual username
    password='your-password'   # Replace with actual password
)

# Step 1: Login
login_response = logestic_sms.login()
print('--------')
print(login_response.status_code)
print(login_response.json())

# Step 2: Send SMS
send_sms_response = logestic_sms.send_one_sms(
    receptor='your-receptor-number',  # Replace with actual receptor number
    message='Your message here',      # Replace with actual message
    sender='your-sender-id'           # Replace with actual sender ID
)
print('--------')
print(send_sms_response.status_code)
print(send_sms_response.json())

# Step 3: Track SMS
if send_sms_response.status_code == 200 and send_sms_response.json().get('msg') == 'success':
    tracking_id = send_sms_response.json().get('data', {}).get('trackingId')
    if tracking_id:
        track_sms_response = logestic_sms.track_sms(tracking_id)
        print('-------------')
        print(track_sms_response.status_code)
        print(track_sms_response.json())

# Step 4: Get Account Info
account_info_response = logestic_sms.get_account_info()
print('-------------')
print(account_info_response.status_code)
print(account_info_response.json())
